| coxstream-package | R Documentation |
Fits the Cox proportional hazards model using a single descending-order pass per Newton-Raphson iteration. Peak RAM is O(p^2) regardless of the number of rows, making it suitable for datasets that do not fit in memory. Produces identical coefficients to survival::coxph() with Efron tie correction.
Maintainer: Tommy Carstensen cran@tommycarstensen.com (ORCID)
Authors:
Tommy Carstensen cran@tommycarstensen.com (ORCID)
Other contributors:
Apache Software Foundation (vendored Arrow C Data/Stream interface header (src/arrow_c_abi.h), Apache-2.0) [copyright holder, contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.